
.. _acoustics_1d_heterogeneous:

Acoustics 1D -- Heterogeneous example
------------------------------------------

1D acoustics in a piecewise constant medium to illustrate reflection and
transmission at an interface.

The density and bulk modulus of the medium are specified in setrun.py,
along with a parameter determining what initial conditions to use
(see qinit.f).

Adapted from `$CLAW/classic/examples/acoustics_1d_heterogeneous`
to use adaptive mesh refinement.
